Learn R Programming

GMZTests (version 0.1.4)

deltadmca.test: Statistical test for Statistical test for DMCA cross-correlation coefficient.

Description

This function performs the statistical test for Detrending moving-average cross-correlation coefficient from two univariate ARFIMA process.

Usage

deltadmca.test(x, y, k, m, rep)

Arguments

x

A vector containing univariate time series.

y

A vector containing univariate time series.

k

An integer value indicating the boundary of the division \((N/k)\). The smallest value of \(k\) is \(4\).

m

an integer value or a vector of integer values indicating the size of the window for the polinomial fit.

rep

An integer value indicating the number of repetitions.

Value

An list containing "timescale", "mean", "sd", "rho_before", "rho_affter", "deltarho", "CI_0.90", "CI_0.95", "CI_0.99".

Details

This function include following measures: timescale, rho_before, rho_affter, deltarho

References

Guedes, et al. Statistical test for DCCA cross-correlation coefficient, Physica A, v.501, 134-140, 2018.

Guedes, et al. Statistical test for DCCA: Methods and data, Data in Brief, v. 18, 795-798, 2018.

Examples

Run this code
# NOT RUN {
x <- rnorm(1000)
y <-  rnorm(1000)
deltadmca.test(x,y,k=100,m=c(4:6),rep=10)

# }

Run the code above in your browser using DataLab