powered by
This function performs the statistical test for Delta RHODCCA cross-correlation coefficient from two univariate ARFIMA process.
deltarhodcca.test(x, y, k, m, nu, rep)
A vector containing univariate time series.
An integer value indicating the boundary of the division \((N/k)\). The smallest value of \(k\) is \(4\).
an integer value or a vector of integer values indicating the size of the window for the polinomial fit.
An integer value. See the DCCA package.
An integer value indicating the number of repetitions.
An list containing "timescale", "mean", "sd", "rho_before", "rho_affter", "deltarho", "CI_0.90", "CI_0.95", "CI_0.99".
This function include following measures: timescale, rho_before, rho_affter, deltarho
Guedes, et al. Statistical test for DCCA cross-correlation coefficient, Physica A, v.501, 134-140, 2018.
Guedes, et al. Statistical test for DCCA: Methods and data, Data in Brief, v. 18, 795-798, 2018.
# NOT RUN { x <- rnorm(1000) y <- rnorm(1000) deltarhodcca.test(x,y,k=100,m=c(4:6),nu=0,rep=10) # }
Run the code above in your browser using DataLab