powered by
This function performs the statistical test for RHODCCA cross-correlation coefficient based in White Gaussian Noise process.
rhodcca.test(N, k, m, nu, rep)
An integer value for the time series length.
An integer value indicating the boundary of the division \((N/k)\). The smallest value of \(k\) is \(4\).
an integer value or a vector of integer values indicating the size of the window for the polinomial fit.
An integer value. See the DCCA package.
An integer value indicating the number of repetitions.
An list containing "timescale","mean", "sd" and confidence interval: "CI_0.90", "CI_0.95", "CI_0.99".
This function include following measures: timescale and cross-correlation yx.
B. Podobnik, Z.-Q. Jiang, W.-X. Zhou, H. E. Stanley, Statistical tests for power-law cross-correlated processes, Phys. Rev.,E 84, 066118, 2011.
# NOT RUN { rhodcca.test(N=100, k=10, m=c(4:6), nu=0, rep=10) # }
Run the code above in your browser using DataLab